@@ -2,26 +2,24 @@
 
 import glob, os
 
-from coverage.backward import string_class, StringIO
+from coverage.backward import open_source, string_class, StringIO
 from coverage.misc import CoverageException
 
 
-def code_unit_factory(morfs, file_locator, omit_prefixes=None):
+def code_unit_factory(morfs, file_locator):
     """Construct a list of CodeUnits from polymorphic inputs.
-    
-    `morfs` is a module or a filename, or a list of same.
-    `file_locator` is a FileLocator that can help resolve filenames.
-    `omit_prefixes` is a list of prefixes.  CodeUnits that match those prefixes
-    will be omitted from the list.
-    
-    Returns a list of CodeUnit objects.
-    
-    """
 
+    `morfs` is a module or a filename, or a list of same.
+
+    `file_locator` is a FileLocator that can help resolve filenames.
+
+    Returns a list of CodeUnit objects.
+
+    """
     # Be sure we have a list.
     if not isinstance(morfs, (list, tuple)):
         morfs = [morfs]
-    
+
     # On Windows, the shell doesn't expand wildcards.  Do it here.
     globbed = []
     for morf in morfs:
@@ -32,33 +30,20 @@ def code_unit_factory(morfs, file_locator, omit_prefixes=None):
     morfs = globbed
 
     code_units = [CodeUnit(morf, file_locator) for morf in morfs]
-    
-    if omit_prefixes:
-        prefixes = [file_locator.abs_file(p) for p in omit_prefixes]
-        filtered = []
-        for cu in code_units:
-            for prefix in prefixes:
-                if cu.name.startswith(prefix):
-                    break
-            else:
-                filtered.append(cu)
-    
-        code_units = filtered
 
     return code_units
 
 
-class CodeUnit:
+class CodeUnit(object):
     """Code unit: a filename or module.
-    
+
     Instance attributes:
-    
+
     `name` is a human-readable name for this code unit.
     `filename` is the os path from which we can read the source.
     `relative` is a boolean.
-    
-    """
 
+    """
     def __init__(self, morf, file_locator):
         self.file_locator = file_locator
 
@@ -91,53 +76,62 @@ class CodeUnit:
 
     # Annoying comparison operators. Py3k wants __lt__ etc, and Py2k needs all
     # of them defined.
-    
-    def __lt__(self, other):
-        return self.name < other.name
-    
-    def __le__(self, other):
-        return self.name <= other.name
 
-    def __eq__(self, other):
-        return self.name == other.name
-    
-    def __ne__(self, other):
-        return self.name != other.name
-
-    def __gt__(self, other):
-        return self.name > other.name
-    
-    def __ge__(self, other):
-        return self.name >= other.name
+    def __lt__(self, other): return self.name <  other.name
+    def __le__(self, other): return self.name <= other.name
+    def __eq__(self, other): return self.name == other.name
+    def __ne__(self, other): return self.name != other.name
+    def __gt__(self, other): return self.name >  other.name
+    def __ge__(self, other): return self.name >= other.name
 
     def flat_rootname(self):
         """A base for a flat filename to correspond to this code unit.
-        
+
         Useful for writing files about the code where you want all the files in
         the same directory, but need to differentiate same-named files from
         different directories.
-        
+
         For example, the file a/b/c.py might return 'a_b_c'
-        
+
         """
         if self.modname:
             return self.modname.replace('.', '_')
         else:
-            root = os.path.splitdrive(os.path.splitext(self.name)[0])[1]
-            return root.replace('\\', '_').replace('/', '_')
+            root = os.path.splitdrive(self.name)[1]
+            return root.replace('\\', '_').replace('/', '_').replace('.', '_')
 
     def source_file(self):
         """Return an open file for reading the source of the code unit."""
         if os.path.exists(self.filename):
             # A regular text file: open it.
-            return open(self.filename)
+            return open_source(self.filename)
 
         # Maybe it's in a zip file?
         source = self.file_locator.get_zip_data(self.filename)
         if source is not None:
             return StringIO(source)
-            
+
         # Couldn't find source.
         raise CoverageException(
             "No source for code %r." % self.filename
             )
+
+    def should_be_python(self):
+        """Does it seem like this file should contain Python?
+
+        This is used to decide if a file reported as part of the exection of
+        a program was really likely to have contained Python in the first
+        place.
+
+        """
+        # Get the file extension.
+        _, ext = os.path.splitext(self.filename)
+
+        # Anything named *.py* should be Python.
+        if ext.startswith('.py'):
+            return True
+        # A file with no extension should be Python.
+        if not ext:
+            return True
+        # Everything else is probably not Python.
+        return False
